from urllib.parse import urljoin
import requests


class GrocyApiClient(object):
    def __init__(self, base_url, api_key):
        self._base_url = base_url
        self._api_key = api_key
        self._headers = {
            "accept": "application/json",
            "GROCY-API-KEY": api_key
        }

    def get_stock(self):
        req_url = urljoin(self._base_url, "stock")
        resp = requests.get(req_url, headers=self._headers)
        return resp.text

    def get_volatile_stock(self):
        req_url = urljoin(self._base_url, "stock/volatile")
        resp = requests.get(req_url, headers=self._headers)
        return resp.text

    def get_product(self, product_id):
        req_url = urljoin(urljoin(self._base_url, "stock/products/"), product_id)
        print(req_url)
        resp = requests.get(req_url, headers=self._headers)
        return resp.text



from .grocy_api_client import GrocyApiClient

class Grocy(object):
    def __init__(self, base_url, api_key):
        self._api_client = GrocyApiClient(base_url, api_key)

    def stock(self, volatile_only = False):
        if(volatile_only):
            return self._api_client.get_volatile_stock()
        else:
            return self._api_client.get_stock()

    def product(self, product_id):
        return self._api_client.get_product(product_id)